clear all
set memory 500m
set more off

** Main regression
local docournotregsprovince = 1
local donatresources = 1
local doelection_nat = 1

** Additional regressions for appendices
local docournotregsprovince_qje  =1
local docournotregsdistrictv2 = 1
local dosplitdetail_capital = 1
local coutnotregsprov1990 = 1

local yearFEType = "year"
local distFETypeCournot = "id1990 fzone"
local distFETypeElection = "id2008 fzone"
local distFETypeOilGas = "id2008 fzone"
local splitvartouse = "_dejure"
local provbordertouse = "2008" /*for calculating the split vars: 2008 for modern borders, 1993 for pre-period borders*/
local provIDmarket = "prov2008" /*for collapsing regression purposes: prov2008 for 2008, prov1990 for historical*/
local provFEType = "prov2008 fzone" /*for province regressionsL prov1990 for old, prov2008 for new*/
local exchangerate = 10000


global OUTDIR "../output/"

cap log close
*log using ${OUTDIR}100712benregs,replace

*******************
* District splits and elections
* District level
*******************

version 11.2


** Prepare data for use
use 00_08_fc_dist08_fisl,clear



** Generate 2008 province ID
g prov2008 = substr(string(id2008),1,2)

* merge in split data from pre 2000 to allow for leads and lags properly
* expand dataset to go back to 1990 and forward to 2010
drop if id2008 == .
count
local obsCount = r(N)
local newObsCount = r(N) + 12
local start = `obsCount' + 1
set obs `newObsCount'
list year if _n >= `start'
for num `start'/`newObsCount' \ num 1990/1999 2009 2010: replace year = Y if _n == X
list year if _n >= `start'
fillin id2008 fzone year
count
sort id2008 year
merge id2008 year using other_data_splits, uniqusing update
tab _merge
drop if _merge == 2 /* non-forest islands */
drop if id2008 == . /* created by fillin due added 1990/1999 obs */
drop if fzone == .  /* created by fillin due added 1990/1999 obs */
drop _merge

	


** fill in the date_election2 variable since it's missing now in 2010
preserve
keep if year == 2008
bys id2008: keep if _n == 1
keep  id2008 end_term2 date_election2
tempfile tempelection
sort id2008
save `tempelection'
restore
sort id2008
merge id2008 using `tempelection',uniqusing update
tab _merge


** generate leads and lags of election variable
egen uniqueid = group(id2008 fzone)
tsset uniqueid year

g elect = (date_election1 == year)
replace elect = 1 if (date_election2 == year)
replace elect = 1 if (end_term2 == year)
for num 1/3: g lXelect = lX.elect
for num 1/3: g fXelect = fX.elect
replace l1elect = 0 if year < 2005 	/* b/c no elections prior to 2005 */
replace l2elect = 0 if year < 2006 	/* b/c no elections prior to 2005 */
replace l3elect = 0 if year < 2007 	/* b/c no elections prior to 2005 */

replace numsplits_nat = numsplits_bps if year < 2000


** genreate leads and lags of split variables
** District 
g numsplits = numsplits`splitvartouse'
for num 1/5: g lXnumsplits = lX.numsplits
for num 1/3: g fXnumsplits = fX.numsplits


for num 1/5: g lXnumsplits_nat = lX.numsplits_nat
for num 1/3: g fXnumsplits_nat = fX.numsplits_nat

** For province aggregates, choose which province definitions to use
for any _bps _dejure _nat city_bps notcity_bps: g numdistrictsX = numdistrictsX_`provbordertouse'
for any bps dejure nat : g othernumdistricts_X = othernumdistricts_X_`provbordertouse'



* Pre-2000, we use the dejure split data. This is really only used to get the lags and leads right.
replace numsplits_dau = numsplits_dejure if year < 2000 & numsplits_dau == .
replace numsplits_nat = numsplits_dejure if year < 2000 & numsplits_nat == . 
replace othernumdistricts_dau = othernumdistricts_dejure if year < 2000 & othernumdistricts_dau == .
replace othernumdistricts_nat = othernumdistricts_dejure if year < 2000 & othernumdistricts_nat == .


replace numdistricts_bps = numdistrictsnotcity_bps + numdistrictscity_bps

*g numdistricts_dau = numsplits_dau + othernumdistricts_dau
*g numdistricts_nat = numsplits_nat + othernumdistricts_nat

g numdistricts = numdistricts`splitvartouse'
*g numdistrictsneighbor = numdistrictsneighbor`splitvartouse'
*g numdistrictsneigwt = numdistrictsneigwt`splitvartouse'

* Generate "numdistrictsinotherprovincesonisland"
preserve
g island = substr(string(prov1990),1,1)
bys prov1990 year: keep if _n == 1
bys island year: egen numdistrictsinisland = total(numdistricts)
g numdistinislnotprov = numdistrictsinisland - numdistricts
keep prov1990 year numdistinislnotprov numdistrictsinisland 
sort prov1990 year
tempfile tempprov
save `tempprov'
restore


****************
* Count districts splits in province with positive log production in any zone
****************

preserve

g templogging = deforest * -1
bys id1990: egen temptotallogging2001 = total(templogging) if year == 2001
bys id1990: egen tempanylogging2001 = mean(temptotallogging2001) 
g anylogging2001 = 1 if tempanylogging2001   > 10 & tempanylogging2001 != .
replace anylogging2001 = 0 if anylogging2001 == .

bys id1990 year: keep if _n ==1
bys prov1990 year: egen tempnumdistricts_wlogprod = total(numsplits) if anylogging2001 == 1
bys prov1990 year: egen numdistricts_wlogprod = mean(tempnumdistricts_wlogprod) 
keep anylogging2001 numdistricts_wlogprod prov1990 year
bys prov1990 year: keep if _n == 1
tempfile numdistlogprod
sort prov1990 year
save `numdistlogprod'
restore

cap drop _merge
sort prov1990 year
merge n:1 prov1990 year using `numdistlogprod'
tab _merge
drop _merge


g tempnumdistwlog90 = numdistricts_wlogprod if year == 1990
bys prov1990: egen numdistricts_wlogprod90 = mean(tempnumdistwlog90)


sort prov1990 year
cap drop _merge
merge n:1 prov1990 year using `tempprov'
tab _merge

tsset 

for num 1/5: g lXnumdistricts = lX.numdistricts
for num 1/3: g fXnumdistricts = fX.numdistricts

g anynewdistinprov = (numdistricts - l.numdistricts) > 0 if numdistricts != . & l.numdistricts!=.
g tempsplityear = year if anynewdistinprov  == 1
bys `provIDmarket': egen firstsplityear = min(tempsplityear) if year >= 2001
g anysplitinprov = year >= firstsplityear
g splitincident = 0
tsset
for num 1991/2008: replace splitincident = l.splitincident if year == X \ replace splitincident = splitincident + 1 if anynewdistinprov==1 & year == X
for num 1/5: g lXanysplitinprov  = lX.anysplitinprov 
for num 1/5: g lXsplitincident  = lX.splitincident

*for num 1/5: g lXnumdistrictsneighbor = lX.numdistrictsneighbor
*for num 1/3: g fXnumdistrictsneighbor = fX.numdistrictsneighbor


*for num 1/5: g lXnumdistrictsneigwt = lX.numdistrictsneigwt
*for num 1/3: g fXnumdistrictsneigwt = fX.numdistrictsneigwt


for num 1/5: g lXnumdistrictsinisland = lX.numdistrictsinisland
for num 1/3: g fXnumdistrictsinisland = fX.numdistrictsinisland

for num 1/5: g lXnumdistinislnotprov = lX.numdistinislnotprov
for num 1/3: g fXnumdistinislnotprov= fX.numdistinislnotprov


for num 1/5: g lXnumdistricts_bps = lX.numdistricts_bps
for num 1/3: g fXnumdistricts_bps= fX.numdistricts_bps

for num 1/5: g lXnumdistrictscity_bps = lX.numdistrictscity_bps
for num 1/3: g fXnumdistrictscity_bps= fX.numdistrictscity_bps

for num 1/5: g lXnumdistrictsnotcity_bps = lX.numdistrictsnotcity_bps
for num 1/3: g fXnumdistrictsnotcity_bps= fX.numdistrictsnotcity_bps



g othernumdistricts = numdistricts`splitvartouse' - numsplits`splitvartouse'
for num 1/5: g lXothernumdistricts = lX.othernumdistricts
for num 1/3: g fXothernumdistricts = fX.othernumdistricts

replace pc_oil_gas = pc_oil_gas / `exchangerate'
replace pc_dau = pc_dau / `exchangerate'
g pc_total = pc_oil_gas + pc_dau
for num 1/5: g lXpc_oil_gas = lX.pc_oil_gas
for num 1/3: g fXpc_oil_gas = fX.pc_oil_gas

replace l1pc_oil_gas = 0 if year <= 2001
replace l2pc_oil_gas = 0 if year <= 2002
replace l3pc_oil_gas = 0 if year <= 2003
replace l4pc_oil_gas = 0 if year <= 2004
replace l5pc_oil_gas = 0 if year <= 2005

for num 1/5: g lXpc_dau = lX.pc_dau
for num 1/3: g fXpc_dau = fX.pc_dau

replace l1pc_dau = 0 if year <= 2001
replace l2pc_dau = 0 if year <= 2002
replace l3pc_dau = 0 if year <= 2003
replace l4pc_dau = 0 if year <= 2004
replace l5pc_dau = 0 if year <= 2005



** now that leads and lags are created, drop pre 2000 obs to speed things up
drop if year < 2000

** make deforestation position
g logging = -1*deforest


* drop extra years
drop if year >= 2009

* generate groups for FE purposes
egen distFEVarCournot = group(`distFETypeCournot')
egen distFEVarElection = group(`distFETypeElection')
egen distFEVarOilGas = group(`distFETypeOilGas')
egen yearFEvar = group(`yearFEType')


g numparties_posdir = 0  if new_bup_off_party_posdir != ""
g tempparty = new_bup_off_party_posdir
foreach X of num 1/20 {
	replace numparties_posdir = numparties_posdir  + 1 if index(tempparty,",") != 0 
	replace tempparty= substr(tempparty,index(tempparty,",")+1,.) if index(tempparty,",") != 0
	}
replace numparties_posdir = . if index(new_bup_off_party_posdir,"Gabungan") != 0 | index(new_bup_off_party_posdir,"Koalisi")  != 0

g bg_posdir = 1 if new_bup_off_bg == "Incumbent" | index(new_bup_off_bg, "Incumbent Bupati") != 0 | index(new_bup_off_bg, "Incumbent Walikota") != 0| index(new_bup_off_bg, "Incumbent Caretaker") != 0
replace bg_posdir = 2 if index(new_bup_off_bg, "Wk") != 0 
replace bg_posdir = 3 if index(new_bup_off_bg, "DPRD") != 0 | index(new_bup_off_bg, "Legisl") != 0 | index(new_bup_off_bg, "MPR") != 0  | index(new_bup_off_bg, "DPD") != 0 
replace bg_posdir = 4 if index(new_bup_off_bg, "PNS") != 0 | index(new_bup_off_bg, "SEKDA") != 0 | index(new_bup_off_bg, "Sekda") != 0  | index(new_bup_off_bg, "Dispenda") != 0 
replace bg_posdir = 5 if index(new_bup_off_bg, "usaha") != 0 | index(new_bup_off_bg, "Wiraswasta") != 0 
label define background 1 "Incumbent" 2 "Vice-incumbent" 3 "Legislature" 4 "Civil service" 5 "Business"
label values bg_posdir background

* count number of parties supporting
	* code prior job
	
	
**************
* Summary statistics
**************
tabstat logging if fzone != 5, by(fzone) stats(mean sd N)
tabstat logging if fzone == 1 | fzone == 3, stats(mean sd N)
tabstat logging if fzone == 2 | fzone == 4, stats(mean sd N)

g logging_1000ha=logging*5.36646/1000
tabstat logging_1000ha if fzone != 5, by(fzone) stats(mean sd N)
tabstat logging_1000ha if fzone == 1 | fzone == 3, stats(mean sd N)
tabstat logging_1000ha if fzone == 2 | fzone == 4, stats(mean sd N)

so fzone year id2008
by fzone year: egen forest_sum=sum(forest)
so fzone year id2008
by fzone year: egen total_sum=sum(total)
so year id2008
by year: egen totalI_sum=sum(total) if fzone!=5
*browse fzone year forest_sum total_sum totalI_sum if id2008==1101 & fzone != 5
drop *_sum


save data_to_analyze,replace


*************
* Splits regressions
*************

if `docournotregsprovince' == 1 {
preserve
		
				
	collapse (sum) logging (mean) forest numdis* l?numdist* f?numdist*, by(fzone year prov1990 yearFEvar `provIDmarket')
	replace logging = . if year == 2000
	
	
	
			cap drop yd*
			cap drop tempisland
			g tempisland = substr(string(prov1990),1,1)
			xi i.yearFEvar*i.tempisland
			for var _I*: ren X yd_X

	
			egen provID = group(`provFEType')
			g island = real(substr(string(prov1990),1,1))
			
			** poisson regs
			xtpqml logging numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}table4_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging numdistricts yd_* if (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}table4_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging numdistricts yd_* if (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}table4_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging numdistricts yd_* if fzone == 1, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}table4_a.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging numdistricts yd_* if fzone == 3, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}table4_a.txt, append excel drop(yd_*) ctitle("Production")
			xtpqml logging numdistricts yd_* if fzone == 2, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}table4_a.txt, append excel drop(yd_*) ctitle("Conservation")
			xtpqml logging numdistricts yd_* if fzone == 4, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}table4_a.txt, append excel drop(yd_*) ctitle("Protection")

			
			*3 lags
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}table4_b.txt, replace excel drop(yd_*) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}table4_b.txt, append excel drop(yd_*) ctitle("Production/Conversion")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}table4_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 1, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}table4_b.txt, append excel drop(yd_*) ctitle("Conversion")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 3, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}table4_b.txt, append excel drop(yd_*) ctitle("Production")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 2, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}table4_b.txt, append excel drop(yd_*) ctitle("Conservation")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 4, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}table4_b.txt, append excel drop(yd_*) ctitle("Protection")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			
			*3 leads and 3 lags
			*Appendix Table 5
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts f1numdistricts f2numdistricts f3numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			lincom f1numdistricts + f2numdistricts + f3numdistricts
			local sumleads = r(estimate)
			local sumleadsse = r(se)
			test f1numdistricts + f2numdistricts + f3numdistricts= 0
			local sumleadsp = r(p)			
			testparm f?numdistricts*
			local jointpleads = r(p)			
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA5.txt, replace excel drop(yd_*) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads",`jointpleads')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts f1numdistricts f2numdistricts f3numdistricts yd_* if (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			lincom f1numdistricts + f2numdistricts + f3numdistricts
			local sumleads = r(estimate)
			local sumleadsse = r(se)
			test f1numdistricts + f2numdistricts + f3numdistricts= 0
			local sumleadsp = r(p)
			testparm f?numdistricts*
			local jointpleads = r(p)			
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA5.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads",`jointpleads')
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts f1numdistricts f2numdistricts f3numdistricts yd_* if (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			lincom f1numdistricts + f2numdistricts + f3numdistricts
			local sumleads = r(estimate)
			local sumleadsse = r(se)
			test f1numdistricts + f2numdistricts + f3numdistricts= 0
			local sumleadsp = r(p)
			testparm f?numdistricts*
			local jointpleads = r(p)			
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA5.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads",`jointpleads')
			
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts f1numdistricts f2numdistricts f3numdistricts yd_* if fzone == 1, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			lincom f1numdistricts + f2numdistricts + f3numdistricts
			local sumleads = r(estimate)
			local sumleadsse = r(se)
			test f1numdistricts + f2numdistricts + f3numdistricts= 0
			local sumleadsp = r(p)
			testparm f?numdistricts*
			local jointpleads = r(p)			
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA5.txt, append excel drop(yd_*) ctitle("Conversion") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads",`jointpleads')
			
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts f1numdistricts f2numdistricts f3numdistricts yd_* if fzone == 3, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			lincom f1numdistricts + f2numdistricts + f3numdistricts
			local sumleads = r(estimate)
			local sumleadsse = r(se)
			test f1numdistricts + f2numdistricts + f3numdistricts= 0
			local sumleadsp = r(p)
			testparm f?numdistricts*
			local jointpleads = r(p)			
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA5.txt, append excel drop(yd_*) ctitle("Production") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads",`jointpleads')
			
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts f1numdistricts f2numdistricts f3numdistricts yd_* if fzone == 2, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			lincom f1numdistricts + f2numdistricts + f3numdistricts
			local sumleads = r(estimate)
			local sumleadsse = r(se)
			test f1numdistricts + f2numdistricts + f3numdistricts= 0
			local sumleadsp = r(p)
			testparm f?numdistricts*
			local jointpleads = r(p)			
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA5.txt, append excel drop(yd_*) ctitle("Conservation") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads",`jointpleads')
			
			
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts f1numdistricts f2numdistricts f3numdistricts yd_* if fzone == 4, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			lincom f1numdistricts + f2numdistricts + f3numdistricts
			local sumleads = r(estimate)
			local sumleadsse = r(se)
			test f1numdistricts + f2numdistricts + f3numdistricts= 0
			local sumleadsp = r(p)
			testparm f?numdistricts*
			local jointpleads = r(p)			
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA5.txt, append excel drop(yd_*) ctitle("Protection") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads",`jointpleads')
			
			
			**APpendix Table A18
			** Dropping 2001
			drop if year == 2001
			
			** poisson regs
			xtpqml logging numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA18_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging numdistricts yd_* if (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA18_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging numdistricts yd_* if (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA18_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging numdistricts yd_* if fzone == 1, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA18_a.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging numdistricts yd_* if fzone == 3, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA18_a.txt, append excel drop(yd_*) ctitle("Production")
			xtpqml logging numdistricts yd_* if fzone == 2, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA18_a.txt, append excel drop(yd_*) ctitle("Conservation")
			xtpqml logging numdistricts yd_* if fzone == 4, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA18_a.txt, append excel drop(yd_*) ctitle("Protection")

			
			*3 lags
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA18_b.txt, replace excel drop(yd_*) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA18_b.txt, append excel drop(yd_*) ctitle("Production/Conversion")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA18_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 1, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA18_b.txt, append excel drop(yd_*) ctitle("Conversion")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 3, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA18_b.txt, append excel drop(yd_*) ctitle("Production")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 2, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA18_b.txt, append excel drop(yd_*) ctitle("Conservation")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 4, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA18_b.txt, append excel drop(yd_*) ctitle("Protection")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			
			restore
			
}



if `donatresources' == 1 {
	

			* Make Island-Year FE
			cap drop yd*
			cap drop tempisland
			g tempisland = substr(string(id2008),1,1)
			xi i.yearFEvar*i.tempisland
			for var _I*: ren X yd_X
			
			
			
			xtpqml logging pc_oil_gas numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}table6_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging pc_oil_gas numsplits_nat yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}table6_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging pc_oil_gas numsplits_nat yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}table6_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			
			*3 lags 
			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}table6_b.txt, replace excel drop(yd_*) ctitle("All Forest") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}table6_b.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}table6_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			
			
			***** Appendix Table 14
			***** PRovince Level clustering
			
			xtpqml logging pc_oil_gas numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(prov2008)
			outreg2 using ${OUTDIR}tableA14_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging pc_oil_gas numsplits_nat yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(prov2008)
			outreg2 using ${OUTDIR}tableA14_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging pc_oil_gas numsplits_nat yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(prov2008)
			outreg2 using ${OUTDIR}tableA14_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			
			*3 lags 
			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(prov2008)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA14_b.txt, replace excel drop(yd_*) ctitle("All Forest") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(prov2008)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA14_b.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(prov2008)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA14_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			
			
			
			*3 lags -- with missing prior to 2004
			preserve
			replace l3pc_oil_gas = . if year < 2004
			replace l2pc_oil_gas = . if year < 2003
			replace l1pc_oil_gas = . if year < 2002
			replace pc_oil_gas = . if year < 2001
			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(prov2008)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA17.txt, replace excel drop(yd_*) ctitle("All Forest") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(prov2008)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA17.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(prov2008)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA17.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			restore
			
			
			
			***
			* Appendix Table A19 
			* Dropping 2001
			
			preserve
			drop if year == 2001
			
			xtpqml logging pc_oil_gas numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA19_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging pc_oil_gas numsplits_nat yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA19_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging pc_oil_gas numsplits_nat yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA19_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			
			*3 lags 
			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA19_b.txt, replace excel drop(yd_*) ctitle("All Forest") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA19_b.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			xtpqml logging pc_oil_gas l1pc_oil_gas l2pc_oil_gas l3pc_oil_gas numsplits_nat l1numsplits_nat l2numsplits_nat l3numsplits_nat yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas + l3pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local sumlagsp = r(p)
			test l1pc_oil_gas + l2pc_oil_gas  + l3pc_oil_gas = 0
			local main_eq_diffp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}tableA19_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Main diff from sum lags p",`main_eq_diffp')

			restore



}



***


if `docournotregsprovince_qje' == 1 {

		
	preserve		
	collapse (sum) logging (mean) forest numdis* l?numdist* f?numdist* *anysplit* *splitinc*, by(fzone year prov1990 yearFEvar `provIDmarket')
	replace logging = . if year == 2000
	

			cap drop yd*
			cap drop tempisland
			g tempisland = substr(string(prov1990),1,1)
			xi i.yearFEvar*i.tempisland
			for var _I*: ren X yd_X

	
			egen provID = group(`provFEType')
			g island = real(substr(string(prov1990),1,1))
		
		
			* robustness table
			* OLS
			* production zone
			g temp2001logging = logging if year == 2001
			bys provID: egen firstlogging = mean(temp2001logging)
			g temp2001forest = forest if year == 2001
			bys provID: egen firstforest = mean(temp2001forest)
			by provID: egen meanlogging = mean(logging)
					
			
			g lnlogging = ln(logging)
					
					
			****** Appendix Table 7
			***** Robustness to OLS with different weights
			* Proportional models
			xtpqml logging numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA7_a.txt, replace excel drop(yd_*) ctitle("Baseline Spec")
			
			areg lnlogging numdistricts yd_* if fzone != 5, absorb(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA7_a.txt, append excel drop(yd_*) ctitle("OLS Log, no weights")
			
			areg lnlogging numdistricts yd_* if fzone != 5 [w=firstforest], absorb(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA7_a.txt, append excel drop(yd_*) ctitle("OLS Log, first year forest weights")
						
			areg lnlogging numdistricts yd_* if fzone != 5 [w=forest], absorb(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA7_a.txt, append excel drop(yd_*) ctitle("OLS Log, first year forest weights")
								
			areg lnlogging numdistricts yd_* if fzone != 5 [w=firstlogging], absorb(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA7_a.txt, append excel drop(yd_*) ctitle("OLS Log, first year logging weights")
			
			areg lnlogging numdistricts yd_* if fzone != 5 [w=meanlogging], absorb(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA7_a.txt, append excel drop(yd_*) ctitle("OLS Log, avg year logging weights")
			
			
			*** W lags
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA7_b.txt, replace excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			
			areg lnlogging numdistricts l1numdistricts l2numdistricts l3numdistricts  yd_* if fzone != 5, absorb(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA7_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			
			areg lnlogging numdistricts l1numdistricts l2numdistricts l3numdistricts  yd_* if fzone != 5 [w=firstforest], absorb(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA7_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')
						
			areg lnlogging numdistricts l1numdistricts l2numdistricts l3numdistricts  yd_* if fzone != 5 [w=forest], absorb(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA7_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')
								
			areg lnlogging numdistricts l1numdistricts l2numdistricts l3numdistricts  yd_* if fzone != 5 [w=firstlogging], absorb(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA7_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')
			
			areg lnlogging numdistricts l1numdistricts l2numdistricts l3numdistricts  yd_* if fzone != 5 [w=meanlogging], absorb(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA7_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')
			
			
			
			
		   ****** Appendix Table 6
		   ****** Robustness to different samples
		
		
			xtpqml logging numdistricts yd_*  if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA6_a.txt, replace excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, replace excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			** Drop Sumatra
			xtpqml logging numdistricts yd_*  if fzone != 5 & island != 1, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island != 1, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			** Drop Kalimantan
			xtpqml logging numdistricts yd_*  if fzone != 5 & island != 6, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island != 6, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


				** Drop Sulawesi
			xtpqml logging numdistricts yd_*  if fzone != 5 & island != 7, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island != 7, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


				** Drop Papua
			xtpqml logging numdistricts yd_*  if fzone != 5 & island != 8, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island != 8, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			
			** Sumatra Only
			xtpqml logging numdistricts yd_*  if fzone != 5 & island == 1, i(provID) 
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island == 1, i(provID) 
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			** Kalimantan only
			xtpqml logging numdistricts yd_*  if fzone != 5 & island == 6, i(provID) 
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island == 6, i(provID) 
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


			** Sulawesi Only
			xtpqml logging numdistricts yd_*  if fzone != 5 & island == 7, i(provID) 
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island == 7, i(provID) 
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


			** Papua only
			xtpqml logging numdistricts yd_*  if fzone != 5 & island == 8, i(provID) 
			outreg2 using ${OUTDIR}tableA6_a.txt, append excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5 & island == 8, i(provID) 
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA6_b.txt, append excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

				
			sort prov2008
			merge m:1 prov2008 using provdata_qje

			****** Appendix Table 4
			****** Robustness to additional trends
			xtpqml logging numdistricts yd_*  if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA4_a.txt, replace excel drop(yd_* ) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_*  if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA4_b.txt, replace excel drop(yd_* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

		
			
			**
			* PcExp * trend
			**
			cap drop _I*
			for var pcexp : g _I_yr_X = (year-2000)*X
			
			xtpqml logging numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA4_a.txt, append excel drop(yd_* _I*) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA4_b.txt, append excel drop(yd_* _I* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			**
			* Pop * trend
			**
			cap drop _I*
			for var pop00 : g _I_yr_X = (year-2000)*X
			
			xtpqml logging numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA4_a.txt, append excel drop(yd_* _I*) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA4_b.txt, append excel drop(yd_* _I* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')
		
		
			**
			* Forest * trend
			**
			cap drop _I*
			for var totalforest2000: g _I_yr_X = (year-2000)*X
			
			xtpqml logging numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA4_a.txt, append excel drop(yd_* _I*) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA4_b.txt, append excel drop(yd_* _I* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			
			**
			* PcExp, Pop, FOrest * trend
			**
			cap drop _I*
			for var pcexp pop00 totalforest2000: g _I_yr_X = (year-2000)*X
			
			xtpqml logging numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA4_a.txt, append excel drop(yd_* _I*) ctitle("All Forest") 
		
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA4_b.txt, append excel drop(yd_* _I* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			** province specific linear trend
			cap drop _I*
			xi i.prov2008|year
			
			* Drop redundant dummies (province FE + one specific trend per island group)
			drop _Iprov2008_*
			drop _IproXyear_10
			drop _IproXyear_21
			drop _IproXyear_14
					
			xtpqml logging numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA4_a.txt, append excel drop(yd_* _I*) ctitle("All Forest") 
		
			/* Note that this regression is not converging now although it converged before-- not sure why*/
			/*xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* _I* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA4_b.txt, append excel drop(yd_* _I* ) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')
			*/
			
			
			*** Appendix Table 9
			*** Cities vs. non-cities
			* Use the BPS district variable to measure cities (kotamadya) vs non-cities (kabupaten)
			replace numdistricts_bps = numdistrictsnotcity_bps + numdistrictscity_bps
									
			*** No cities
			xtpqml logging numdistrictsnotcity_bps yd_* if  fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_a.txt, replace drop(yd_*) ctitle("All Forest") 
			xtpqml logging numdistrictsnotcity_bps yd_* if  (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging numdistrictsnotcity_bps yd_* if  (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging numdistrictsnotcity_bps yd_* if  fzone == 1, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_a.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging numdistrictsnotcity_bps yd_* if  fzone == 3, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_a.txt, append excel drop(yd_*) ctitle("Production")
			xtpqml logging numdistrictsnotcity_bps yd_* if  fzone == 2, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_a.txt, append excel drop(yd_*) ctitle("Conservation")
			xtpqml logging numdistrictsnotcity_bps yd_* if  fzone == 4, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_a.txt, append excel drop(yd_*) ctitle("Protection")

			*** Cities
			xtpqml logging numdistrictscity_bps yd_* if  fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_b.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging numdistrictscity_bps yd_* if  (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_b.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging numdistrictscity_bps yd_* if  (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging numdistrictscity_bps yd_* if  fzone == 1, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_b.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging numdistrictscity_bps yd_* if  fzone == 3, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_b.txt, append excel drop(yd_*) ctitle("Production")
			xtpqml logging numdistrictscity_bps yd_* if  fzone == 2, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_b.txt, append excel drop(yd_*) ctitle("Conservation")
			xtpqml logging numdistrictscity_bps yd_* if  fzone == 4, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA9_b.txt, append excel drop(yd_*) ctitle("Protection")

			
			restore
			
			
			

			
}





****
* District level data
*****


if `docournotregsdistrictv2' == 1 {
	preserve

	     * collapse to 1990 district level
		 collapse (sum) logging (mean) numsplits l?numsplits f?numsplits othernumdistricts l?othernumdistricts f?othernumdistricts , by(year id1990 fzone yearFEvar)
		 g id2008 = id1990
		 g prov2008 = substr(string(id1990),1,2)
		 egen distFEVarCournot = group(`distFETypeCournot')
		 replace logging = . if year == 2000
		
	
			cap drop yd*
			cap drop tempisland
			g tempisland = substr(string(id2008),1,1)
			xi i.yearFEvar*i.tempisland
			for var _I*: ren X yd_X
		
			tsset,clear
			bootstrap, cluster(prov2008) reps(200): xtpoisson logging numsplits othernumdistricts yd_* if fzone != 5, i(distFEVarCournot) fe
			outreg2 using ${OUTDIR}tableA8_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			bootstrap, cluster(prov2008) reps(200): xtpoisson logging numsplits othernumdistricts yd_* if (fzone == 1 | fzone == 3), i(distFEVarCournot) fe
			outreg2 using ${OUTDIR}tableA8_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			bootstrap, cluster(prov2008) reps(200): xtpoisson logging numsplits othernumdistricts yd_* if (fzone == 2 | fzone == 4), i(distFEVarCournot) fe
			outreg2 using ${OUTDIR}tableA8_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			
			
			*3 lags
			bootstrap, cluster(prov2008) reps(200): xtpoisson logging numsplits l1numsplits l2numsplits l3numsplits othernumdistricts l1othernumdistricts l2othernumdistricts l3othernumdistricts yd_* if fzone != 5, i(distFEVarCournot) fe
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts= 0
			local sumlagsp = r(p)
			testparm *othernumdistricts*
			outreg2 using ${OUTDIR}tableA8_b.txt, replace excel drop(yd_*) ctitle("All Forest") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			bootstrap, cluster(prov2008) reps(200): xtpoisson logging numsplits l1numsplits l2numsplits l3numsplits othernumdistricts l1othernumdistricts l2othernumdistricts l3othernumdistricts yd_* if (fzone == 1 | fzone == 3), i(distFEVarCournot) fe
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts= 0
			local sumlagsp = r(p)
			testparm *othernumdistricts*
			outreg2 using ${OUTDIR}tableA8_b.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			bootstrap, cluster(prov2008) reps(200): xtpoisson logging numsplits l1numsplits l2numsplits l3numsplits othernumdistricts l1othernumdistricts l2othernumdistricts l3othernumdistricts yd_* if (fzone == 2 | fzone == 4), i(distFEVarCournot) fe
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts= 0
			local sumlagsp = r(p)
			testparm *othernumdistricts*
			outreg2 using ${OUTDIR}tableA8_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
		
		
			
			*5 lags
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits l4numsplits l5numsplits othernumdistricts l1othernumdistricts l2othernumdistricts l3othernumdistricts l4othernumdistricts l5othernumdistricts yd_* if fzone != 5, i(distFEVarCournot) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits + l4numsplits + l5numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits + l4numsplits + l5numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts + l4othernumdistricts + l5othernumdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts + l4othernumdistricts + l5othernumdistricts= 0
			local sumlagsp = r(p)
			testparm *othernumdistricts*
			outreg2 using ${OUTDIR}tableA12.txt, replace excel drop(yd_*) ctitle("All Forest") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits l4numsplits l5numsplits othernumdistricts l1othernumdistricts l2othernumdistricts l3othernumdistricts l4othernumdistricts  l5othernumdistricts yd_* if (fzone == 1 | fzone == 3), i(distFEVarCournot) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits + l4numsplits + l5numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits + l4numsplits + l5numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts + l4othernumdistricts + l5othernumdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts + l4othernumdistricts + l5othernumdistricts= 0
			local sumlagsp = r(p)
			testparm *othernumdistricts*
			outreg2 using ${OUTDIR}tableA12.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits l4numsplits l5numsplits othernumdistricts l1othernumdistricts l2othernumdistricts l3othernumdistricts l4othernumdistricts  l5othernumdistricts yd_* if (fzone == 2 | fzone == 4), i(distFEVarCournot) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits + l4numsplits + l5numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits + l4numsplits + l5numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts + l4othernumdistricts + l5othernumdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test othernumdistricts + l1othernumdistricts + l2othernumdistricts + l3othernumdistricts + l4othernumdistricts + l5othernumdistricts= 0
			local sumlagsp = r(p)
			testparm *othernumdistricts*
			outreg2 using ${OUTDIR}tableA12.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			
			
			
			
		restore
}

****


if `dosplitdetail_capital' == 1 {
       * get capital dataset ready
	   preserve
	   use master_kecamaten.dta,clear
	   collapse has*, by(id2008)
	   for var has*: assert X == 1 | X == 0 | X == .
	   
	   *generate districts where we can identify both the 1997 capital and the 2003 capital
	   for var has*: replace X = . if has1997capitalinid1997borders == 0 | has2003capitalinid2003borders == 0 |  has1997capitalinid1997borders == . | has2003capitalinid2003borders == .

	      
	   g has1997capitalin2008 = has1997capitalinid2008borders
	   	   
	   reshape long has1997capitalinid , i(id2008) j(yearstr) string
	   g year = real(substr(yearstr,1,4))
	   keep if year == 2008
	   
		tempfile temp1
		sort id2008 year
		save `temp1'
		
		restore
		cap drop _merge
		sort id2008 year
		
		merge n:1 id2008 using `temp1'
		tab _merge
		
		
		
		

		cap drop yd*
		cap drop tempisland
		g tempisland = substr(string(prov1990),1,1)
		xi i.yearFEvar*i.tempisland
		for var _I*: ren X yd_X

	
		**** Appendix Table 13
		**** Interact splits wtih having 1997 capital in 2008 borders
		g numsplits_hascap = numsplits*has1997capitalin2008
		for num 1/3: g lXnumsplits_hascap = lXnumsplits*has1997capitalin2008
		
		xtpqml logging numsplits numsplits_hascap yd_* if fzone != 5, i(id2008) cluster(id1990)
		outreg2 using ${OUTDIR}tableA13_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
		xtpqml logging numsplits numsplits_hascap yd_* if (fzone == 1 | fzone == 3), i(id2008) cluster(id1990)
		outreg2 using ${OUTDIR}tableA13_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
		xtpqml logging numsplits numsplits_hascap yd_* if (fzone == 2 | fzone == 4), i(id2008) cluster(id1990)
		outreg2 using ${OUTDIR}tableA13_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
		xtpqml logging numsplits numsplits_hascap yd_* if fzone == 1, i(id2008) cluster(id1990)
		outreg2 using ${OUTDIR}tableA13_a.txt, append excel drop(yd_*) ctitle("Conversion")
		xtpqml logging numsplits numsplits_hascap yd_* if fzone == 3, i(id2008) cluster(id1990)
		outreg2 using ${OUTDIR}tableA13_a.txt, append excel drop(yd_*) ctitle("Production")
		xtpqml logging numsplits numsplits_hascap yd_* if fzone == 2, i(id2008) cluster(id1990)
		outreg2 using ${OUTDIR}tableA13_a.txt, append excel drop(yd_*) ctitle("Conservation")
		xtpqml logging numsplits numsplits_hascap yd_* if fzone == 4, i(id2008) cluster(id1990)
		outreg2 using ${OUTDIR}tableA13_a.txt, append excel drop(yd_*) ctitle("Protection")
		
		*3 lags
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits numsplits_hascap l1numsplits_hascap l2numsplits_hascap l3numsplits_hascap yd_* if fzone != 5, i(id2008) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap= 0
			local sumlagsp = r(p)
			testparm *numsplits_hascap*
			outreg2 using ${OUTDIR}tableA13_b.txt, replace drop(yd_*) ctitle("All Forest") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits numsplits_hascap l1numsplits_hascap l2numsplits_hascap l3numsplits_hascap yd_* if (fzone == 1 | fzone == 3), i(id2008) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap= 0
			local sumlagsp = r(p)
			testparm *numsplits_hascap*
			outreg2 using ${OUTDIR}tableA13_b.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits numsplits_hascap l1numsplits_hascap l2numsplits_hascap l3numsplits_hascap yd_* if (fzone == 2 | fzone == 4), i(id2008) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap= 0
			local sumlagsp = r(p)
			testparm *numsplits_hascap*
			outreg2 using ${OUTDIR}tableA13_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits numsplits_hascap l1numsplits_hascap l2numsplits_hascap l3numsplits_hascap yd_* if fzone == 1, i(id2008) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap= 0
			local sumlagsp = r(p)
			testparm *numsplits_hascap*
			outreg2 using ${OUTDIR}tableA13_b.txt, append excel drop(yd_*) ctitle("Conversion") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits numsplits_hascap l1numsplits_hascap l2numsplits_hascap l3numsplits_hascap yd_* if fzone == 3, i(id2008) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap= 0
			local sumlagsp = r(p)
			testparm *numsplits_hascap*
			outreg2 using ${OUTDIR}tableA13_b.txt, append excel drop(yd_*) ctitle("Production") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits numsplits_hascap l1numsplits_hascap l2numsplits_hascap l3numsplits_hascap yd_* if fzone == 2, i(id2008) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap= 0
			local sumlagsp = r(p)
			testparm *numsplits_hascap*
			outreg2 using ${OUTDIR}tableA13_b.txt, append excel drop(yd_*) ctitle("Conservation") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
			
			xtpqml logging numsplits l1numsplits l2numsplits l3numsplits numsplits_hascap l1numsplits_hascap l2numsplits_hascap l3numsplits_hascap yd_* if fzone == 4, i(id2008) cluster(id1990)
			lincom numsplits + l1numsplits + l2numsplits + l3numsplits
			local nssumlags = r(estimate)
			local nssumlagsse = r(se)
			test numsplits + l1numsplits + l2numsplits + l3numsplits= 0
			local nssumlagsp = r(p)
			testparm *numsplits
			local nssumlagsjointp = r(p)
			lincom numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numsplits_hascap + l1numsplits_hascap + l2numsplits_hascap + l3numsplits_hascap= 0
			local sumlagsp = r(p)
			testparm *numsplits_hascap*
			outreg2 using ${OUTDIR}tableA13_b.txt, append excel drop(yd_*) ctitle("Protection") adds("Num splits joint P",`nssumlagsjointp',"Num splits sum lags",`nssumlags',"Num splits sum lags se",`nssumlagsse',"Num splits sum lags p",`nssumlagsp',"Other Joint P",r(p),"Other sum lags",`sumlags',"Other sum lags se",`sumlagsse',"Other sum lags p",`sumlagsp')
		
		
		
}


if `doelection_nat' == 1 {
	
	
	g postelection = year > date_election1 if date_election1 != .
	g postelection_numcand = postelection * new_bup_nocand_posdir  
	g postelection_incumbent = postelection * new_bup_incumbent_posdir  
	g postelection_numparties = postelection * numparties_posdir 
	g postelec_pc_oil_gas = postelection * pc_oil_gas
	
	g temppc_oil_gas_2003 = pc_oil_gas if year == 2003
	bys id2008: egen pc_oil_gas_2003 = mean(temppc_oil_gas_2003)
	
	g postelection_pcog_2003 = postelection * pc_oil_gas_2003
	
			cap drop yd*
			cap drop tempisland
			g tempisland = substr(string(id2008),1,1)
			xi i.yearFEvar*i.tempisland
			for var _I*: ren X yd_X
		
						
			**** Table 7
			xtpqml logging postelection postelec_pc_oil_gas pc_oil_gas numsplits_nat yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + postelec_pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + postelec_pc_oil_gas=0 
			local sumlagsp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}table7.txt, replace excel drop(yd_*) ctitle("All Forest") adds("Joint P",r(p),"Sum pc_oil + interaction",`sumlags',"Sum pc_oil + interaction se",`sumlagsse',"Sum pc_oil + interaction p",`sumlagsp')

			xtpqml logging postelection postelec_pc_oil_gas pc_oil_gas numsplits_nat  yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			lincom pc_oil_gas + postelec_pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + postelec_pc_oil_gas=0 
			local sumlagsp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}table7.txt, append excel drop(yd_*) ctitle("Production/Conversion") adds("Joint P",r(p),"Sum pc_oil + interaction",`sumlags',"Sum pc_oil + interaction se",`sumlagsse',"Sum pc_oil + interaction p",`sumlagsp')
			
			xtpqml logging postelection postelec_pc_oil_gas pc_oil_gas numsplits_nat  yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
				lincom pc_oil_gas + postelec_pc_oil_gas
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test pc_oil_gas + postelec_pc_oil_gas=0 
			local sumlagsp = r(p)
			testparm *pc_oil_gas*
			outreg2 using ${OUTDIR}table7.txt, append excel drop(yd_*) ctitle("Conservation/Protection") adds("Joint P",r(p),"Sum pc_oil + interaction",`sumlags',"Sum pc_oil + interaction se",`sumlagsse',"Sum pc_oil + interaction p",`sumlagsp')
			
			
			*** Appendix Table A16
			* numcand
			xtpqml logging postelection postelection_numcand  yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging postelection postelection_numcand  yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging postelection postelection_numcand  yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging postelection postelection_numcand  yd_* if fzone == 1, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_a.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging postelection postelection_numcand  yd_* if fzone == 3, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_a.txt, append drop(yd_*) ctitle("Production")
			xtpqml logging postelection postelection_numcand  yd_* if fzone == 2, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_a.txt, append drop(yd_*) ctitle("Conservation")
			xtpqml logging postelection postelection_numcand  yd_* if fzone == 4, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_a.txt, append excel drop(yd_*) ctitle("Protection")
			
			* numparties
			xtpqml logging postelection postelection_numparties  yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_b.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging postelection postelection_numparties  yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_b.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging postelection postelection_numparties  yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging postelection postelection_numparties  yd_* if fzone == 1, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_b.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging postelection postelection_numparties  yd_* if fzone == 3, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_b.txt, append excel drop(yd_*) ctitle("Production")
			xtpqml logging postelection postelection_numparties  yd_* if fzone == 2, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_b.txt, append excel drop(yd_*) ctitle("Conservation")
			xtpqml logging postelection postelection_numparties  yd_* if fzone == 4, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_b.txt, append excel drop(yd_*) ctitle("Protection")
			
			
			* incumbent
			xtpqml logging postelection postelection_incumbent  yd_* if fzone != 5, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_c.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging postelection postelection_incumbent  yd_* if (fzone == 1 | fzone == 3), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_c.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging postelection postelection_incumbent  yd_* if (fzone == 2 | fzone == 4), i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_c.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging postelection postelection_incumbent  yd_* if fzone == 1, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_c.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging postelection postelection_incumbent  yd_* if fzone == 3, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_c.txt, append excel drop(yd_*) ctitle("Production")
			xtpqml logging postelection postelection_incumbent  yd_* if fzone == 2, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_c.txt, append excel drop(yd_*) ctitle("Conservation")
			xtpqml logging postelection postelection_incumbent  yd_* if fzone == 4, i(distFEVarOilGas) cluster(id1990)
			outreg2 using ${OUTDIR}tableA16_c.txt, append excel drop(yd_*) ctitle("Protection")
			
			
			
		

	
	preserve
	
	drop *elect_posdir* new_bup_off_party_posdir

	collapse (mean) *posdir *pc_oil* *elect* , by(id2008 year)
	
	g island = substr(string(id2008),1,1)
	g delt2003oil = (pc_oil_gas - pc_oil_gas_2003) / (year - 2003)

	*** Appendix Table A15
	
	
	foreach Yvar of var new_bup_nocand_posdir  numparties_posdir new_bup_incumbent_posdir  {
		* levels
		reg `Yvar' pc_oil_gas if year == date_election1, robust
		outreg2 using ${OUTDIR}tableA15_a_`Yvar'.txt, replace 
		xi: areg `Yvar' pc_oil_gas i.year if year == date_election1, robust absorb(island)
		outreg2 using ${OUTDIR}tableA15_a_`Yvar'.txt,  drop(*_I*)
				
		* intial level + recent change
		reg `Yvar' pc_oil_gas_2003 delt2003oil if year == date_election1, robust
		outreg2 using ${OUTDIR}tableA15_b_`Yvar'.txt, 
		
		xi: areg `Yvar' pc_oil_gas_2003 delt2003oil i.year if year == date_election1, robust absorb(island)
		outreg2 using ${OUTDIR}tableA15_b_`Yvar'.txt, excel word drop(*_I*)
		
		
	}
	restore
	
	
}


if `coutnotregsprov1990' == 1 {
preserve
		
				
	collapse (sum) logging (mean) forest numdis* l?numdist* f?numdist*, by(fzone year prov1990)
	replace logging = . if year == 2000
	
	
	
			cap drop yd*
			cap drop tempisland
			g tempisland = substr(string(prov1990),1,1)
			xi i.year*i.tempisland
			for var _I*: ren X yd_X

	
			egen provID = group(prov1990)
			g island = real(substr(string(prov1990),1,1))
			
			
			****
			* Appendix Table 20
			* Collapsed to 1990 provincial border level
			**** 
			
			** poisson regs
			xtpqml logging numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA20_a.txt, replace excel drop(yd_*) ctitle("All Forest") 
			xtpqml logging numdistricts yd_* if (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA20_a.txt, append excel drop(yd_*) ctitle("Production/Conversion")
			xtpqml logging numdistricts yd_* if (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA20_a.txt, append excel drop(yd_*) ctitle("Conservation/Protection")
			xtpqml logging numdistricts yd_* if fzone == 1, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA20_a.txt, append excel drop(yd_*) ctitle("Conversion")
			xtpqml logging numdistricts yd_* if fzone == 3, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA20_a.txt, append excel drop(yd_*) ctitle("Production")
			xtpqml logging numdistricts yd_* if fzone == 2, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA20_a.txt, append excel drop(yd_*) ctitle("Conservation")
			xtpqml logging numdistricts yd_* if fzone == 4, i(provID) cluster(prov1990)
			outreg2 using ${OUTDIR}tableA20_a.txt, append excel drop(yd_*) ctitle("Protection")

			
			*3 lags
			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone != 5, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA20_b.txt, replace excel drop(yd_*) ctitle("All Forest")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if (fzone == 1 | fzone == 3), i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA20_b.txt, append excel drop(yd_*) ctitle("Production/Conversion")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if (fzone == 2 | fzone == 4), i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA20_b.txt, append excel drop(yd_*) ctitle("Conservation/Protection")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 1, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA20_b.txt, append excel drop(yd_*) ctitle("Conversion")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 3, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA20_b.txt, append excel drop(yd_*) ctitle("Production")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 2, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA20_b.txt, append excel drop(yd_*) ctitle("Conservation")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

			xtpqml logging numdistricts l1numdistricts l2numdistricts l3numdistricts yd_* if fzone == 4, i(provID) cluster(prov1990)
			lincom numdistricts + l1numdistricts + l2numdistricts + l3numdistricts
			local sumlags = r(estimate)
			local sumlagsse = r(se)
			test numdistricts + l1numdistricts + l2numdistricts + l3numdistricts= 0
			local sumlagsp = r(p)
			testparm *numdistricts
			outreg2 using ${OUTDIR}tableA20_b.txt, append excel drop(yd_*) ctitle("Protection")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

}
